@@ -506,7 +506,7 @@ class BaseWidgetContainer
 	 * @param int $year			年
 	 * @param int $month			月
 	 * @param int $day			日
-	 * @return 						なし
+	 * @return bool					true=成功、false失敗
 	 */
 	function timestampToYearMonthDay($datestr, &$year, &$month, &$day)
 	{
@@ -515,11 +515,35 @@ class BaseWidgetContainer
 		$dd = '';
 		$ret_stat = '';
 		list($srcstr, $dummy) = split(' ', $datestr);
-		if (strlen($datestr) == 0) return "";
+		if (strlen($datestr) == 0) return false;
 		list($yyyy, $mm, $dd) = split('[/.-]', $srcstr);
 		$year = intval($yyyy);
 		$month = intval($mm);
 		$day = intval($dd);
+		return true;
+	}
+	/**
+	 * Timestamp型の値から時分秒を取得
+	 *
+	 * @param timestamp $datestr	Timestamp型の値
+	 * @param int $hour				時
+	 * @param int $minute			分
+	 * @param int $second			秒
+	 * @return bool					true=成功、false失敗
+	 */
+	function timestampToHourMinuteSecond($datestr, &$hour, &$minute, &$second)
+	{
+		$hh = '';
+		$mm = '';
+		$ss = '';
+		$ret_stat = '';
+		list($dummy, $srcstr) = split(' ', $datestr);// 後半を取得
+		if (strlen($datestr) == 0) return false;
+		list($hh, $mm, $ss) = split('[-:]', $srcstr);
+		$hour = intval($hh);
+		$minute = intval($mm);
+		$second = intval($ss);
+		return true;
 	}
 	/**
 	 * 簡易日付(mm/dd, yy/m/d,etc)形式で入力された文字列を正式な日付表現(yyyy/mm/dd)に変換
