@@ -99,7 +99,8 @@ class BaseDb
 					self::$_con->setAttribute(PDO::MYSQL_ATTR_USE_BUFFERED_QUERY, true);
 					
 					// 文字化け防止SQL実行(MySQL4.1以上)
-					if (self::$_dbVersion >= '4.1') self::$_con->exec('SET NAMES utf8');
+					//if (self::$_dbVersion >= '4.1') self::$_con->exec('SET NAMES utf8');
+					self::$_con->exec('SET NAMES utf8');
 				}
 			} catch (PDOException $e) {
 				// 共通エラー処理
