@@ -566,14 +566,16 @@ INSERT INTO _mail_form (mf_id,           mf_language_id, mf_subject,         mf_
 VALUES                 ('contact_us', 'ja',              'お問い合わせ',     '以下のお問い合わせがありました。\n\n[#BODY#]',                             now());
 
 -- 管理画面メニューデータ
-DELETE FROM _nav_item WHERE ni_id >= 100;
+DELETE FROM _nav_item WHERE ni_id >= 500 AND ni_id < 1000;
 INSERT INTO _nav_item
-(ni_id, ni_parent_id, ni_index, ni_nav_id,    ni_task_id,                     ni_top_page_index, ni_name) VALUES
-(100,   0,            10,       'admin_menu', 'widget',                       0,                 'ウィジェット詳細'),
-(101,   100,          0,        'admin_menu', 'configwidget_default_content', 10,                'コンテンツ管理'),
-(102,   100,          1,        'admin_menu', 'configwidget_ec_main',         11,                'Eコマース'),
-(103,   100,          2,        'admin_menu', 'configwidget_blog_main',       12,                'ブログ'),
-(104,   100,          3,        'admin_menu', 'configwidget_bbs_main',        13,                '掲示板');
+(ni_id, ni_parent_id, ni_index, ni_nav_id,    ni_task_id,                     ni_group_id, ni_param, ni_name,    ni_help_title, ni_help_body, ni_visible) VALUES
+(500,   0,            3,        'admin_menu', '_widget',                      '',          '',       'ウィジェット設定', 'ウィジェット設定', '個別のウィジェットの設定を行います。', true),
+(501,   500,          0,        'admin_menu', 'configwidget_default_mainmenu','',          '',          'メインメニュー', 'メインメニュー', 'Webサイトで常時表示するメニューを作成します。', true),
+(502,   500,          1,        'admin_menu', 'configwidget_default_content', '',          '',       'コンテンツビュー', 'デフォルトコンテンツビュー', 'Webサイトのコンテンツを管理する設定画面です。', true),
+(503,   500,          2,        'admin_menu', 'configwidget_ec_main',         '',          '',       'Eコマースメイン', 'Eコマースメイン', 'Eコマース機能のメインとなる設定画面です。', true),
+(504,   500,          3,        'admin_menu', 'configwidget_blog_main',       '',          '',       'ブログメイン', 'ブログメイン', 'ブログ機能のメインとなる設定画面です。', true),
+(505,   500,          4,        'admin_menu', 'configwidget_bbs_main',        '',          '',       '掲示板メイン', '掲示板メイン', '掲示板機能のメインとなる設定画面です。', true),
+(506,   500,          5,        'admin_menu', 'configwidget_reserve_main',        '',          '',   '予約メイン', '予約メイン', '汎用予約機能のメインとなる設定画面です。', true);
 
 -- ウィジェット情報
 DELETE FROM _widgets WHERE wd_id = 'default_mainmenu';
