@@ -151,7 +151,7 @@ class contactusWidgetContainer extends BaseWidgetContainer
 					
 					// メールを送信
 					if (empty($toAddress)){
-						$gErrorManager->writeError(__METHOD__, "サイト情報のEメールアドレスが設定されていません。\n(メール本文)\n" . $mailBody);
+						$gErrorManager->writeError(__METHOD__, "基本情報のEメールアドレスが設定されていません。\n(メール本文)\n" . $mailBody);
 					} else {
 						$mailParam = array();
 						$mailParam['BODY'] = $mailBody;
