@@ -115,7 +115,7 @@ class ec_mainDelivAddressWidgetContainer extends BaseWidgetContainer
 					// 現在のログインユーザを購入者とする。購入者のID(会員ID)を取得
 					$custm_id = 0;
 					$ret = $this->db->getMember($this->userId, $memberRow);
-					if ($ret) $custm_id = $memberRow['sm_id'];
+					if ($ret) $custm_id = $memberRow['sm_id'] * (-1);		// 会員IDに「-」を付けて格納
 					
 					// 顧客は購入者の情報
 					$custm_name = $personInfo['pi_family_name'] . $personInfo['pi_first_name'];
