@@ -116,7 +116,7 @@ class ec_mainDeliveryWidgetContainer extends BaseWidgetContainer
 			$this->checkNumeric($this->state, '都道府県');
 			$this->checkInput($address, '住所');	
 			$this->checkSingleByte($phone, '電話番号');
-			$this->checkInput($this->deliveryMethod, 'お届け方法');
+			$this->checkInput($this->deliveryMethod, 'お届け方法', 'お届け方法が選択されていません');
 			// エラーなしの場合
 			if ($this->getMsgCount() == 0){
 				// 購入者の情報を取得
@@ -125,7 +125,7 @@ class ec_mainDeliveryWidgetContainer extends BaseWidgetContainer
 					// 現在のログインユーザを購入者とする。購入者のID(会員ID)を取得
 					$custm_id = 0;
 					$ret = $this->db->getMember($this->userId, $memberRow);
-					if ($ret) $custm_id = $memberRow['sm_id'];
+					if ($ret) $custm_id = $memberRow['sm_id'] * (-1);		// 会員IDに「-」を付けて格納
 
 					// 顧客は購入者の情報
 					$custm_name = $personInfo['pi_family_name'] . $personInfo['pi_first_name'];
