@@ -53,8 +53,20 @@ class viewDb extends BaseDb
 		$queryStr .=    'AND pt_visible = true ';		// 表示可能な商品	
 		$queryStr .=    'AND pt_language_id = ? ';
 		if (!empty($categoryId)) $queryStr .=    'AND pw_category_id in (' . $categoryId . ') ';
+		
+		$serialArray = array();
+		$ret = $this->selectRecords($queryStr, array($lang), $serialRows);
+		if ($ret){
+			for ($i = 0; $i < count($serialRows); $i++){
+				$serialArray[] = $serialRows[$i]['pt_serial'];
+			}
+		}
+		$serialStr = implode(',', $serialArray);
+
+		$queryStr = 'SELECT * FROM product ';
+		if (!empty($serialStr)) $queryStr .=  'WHERE pt_serial in (' . $serialStr . ') ';
 		$queryStr .=  'ORDER BY pt_sort_order limit ' . $limit . ' offset ' . $offset;
-		$this->selectLoop($queryStr, array($lang), $callback, null);
+		$this->selectLoop($queryStr, array(), $callback, null);
 	}
 	/**
 	 * 商品総数を取得
